@@ -1,12 +1,12 @@
 /*
   alien.c
 
-  alien, Modifies the colours of the image.
+  "Color Shift" aka "Alien": Modifies the colours of the image.
   Tux Paint - A simple drawing program for children.
 
   Credits: Andrew Corcoran <akanewbie@gmail.com> inspired by the Alien Map GIMP plugin
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -25,7 +25,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 23, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -71,6 +71,10 @@ const int alien_groups[alien_NUM_TOOLS] = {
   MAGIC_TYPE_COLOR_FILTERS,
 };
 
+const int alien_orders[alien_NUM_TOOLS] = {
+  601,
+};
+
 const char *alien_descs[alien_NUM_TOOLS][2] = {
   {gettext_noop("Click and drag the mouse to change the colors in parts of your picture."),
    gettext_noop("Click to change the colors in your entire picture."),},
@@ -78,11 +82,12 @@ const char *alien_descs[alien_NUM_TOOLS][2] = {
 
 // Prototypes
 Uint32 alien_api_version(void);
-int alien_init(magic_api * api, Uint32 disabled_features);
+int alien_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int alien_get_tool_count(magic_api * api);
 SDL_Surface *alien_get_icon(magic_api * api, int which);
 char *alien_get_name(magic_api * api, int which);
 int alien_get_group(magic_api * api, int which);
+int alien_get_order(int which);
 char *alien_get_description(magic_api * api, int which, int mode);
 void alien_drag(magic_api * api, int which, SDL_Surface * canvas,
                 SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect);
@@ -110,7 +115,7 @@ Uint32 alien_api_version(void)
 }
 
 //Load sounds
-int alien_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int alien_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   int i;
   char fname[1024];
@@ -125,13 +130,13 @@ int alien_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
   return (1);
 }
 
-int alien_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int alien_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (alien_NUM_TOOLS);
 }
 
 // Load our icons:
-SDL_Surface *alien_get_icon(magic_api * api, int which)
+SDL_Surface *alien_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -140,25 +145,30 @@ SDL_Surface *alien_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char *alien_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *alien_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
-  return (strdup(gettext_noop(alien_names[which])));
+  return (strdup(gettext(alien_names[which])));
 }
 
-int alien_get_group(magic_api * api ATTRIBUTE_UNUSED, int which)
+int alien_get_group(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   return alien_groups[which];
 }
 
-// Return our descriptions, localized:
-char *alien_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+int alien_get_order(int which)
 {
-  return (strdup(gettext_noop(alien_descs[which][mode - 1])));
+  return alien_orders[which];
+}
+
+// Return our descriptions, localized:
+char *alien_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
+{
+  return (strdup(gettext(alien_descs[which][mode - 1])));
 }
 
 //Do the effect for one pixel
 static void do_alien_pixel(void *ptr, int which ATTRIBUTE_UNUSED,
-                           SDL_Surface * canvas, SDL_Surface * last ATTRIBUTE_UNUSED, int x, int y)
+                           SDL_Surface *canvas, SDL_Surface *last ATTRIBUTE_UNUSED, int x, int y)
 {
   magic_api *api = (magic_api *) ptr;
 
@@ -180,7 +190,7 @@ static void do_alien_pixel(void *ptr, int which ATTRIBUTE_UNUSED,
 }
 
 // Do the effect for the full image
-static void do_alien_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, int which)
+static void do_alien_full(void *ptr, SDL_Surface *canvas, SDL_Surface *last, int which)
 {
   int x, y;
 
@@ -194,7 +204,7 @@ static void do_alien_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, i
 }
 
 //do the effect for the brush
-static void do_alien_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_alien_brush(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   magic_api *api = (magic_api *) ptr;
@@ -212,8 +222,8 @@ static void do_alien_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surfa
 }
 
 // Affect the canvas on drag:
-void alien_drag(magic_api * api, int which, SDL_Surface * canvas,
-                SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void alien_drag(magic_api *api, int which, SDL_Surface *canvas,
+                SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
 
   api->line((void *)api, which, canvas, last, ox, oy, x, y, 1, do_alien_brush);
@@ -256,8 +266,8 @@ Mix_Chunk *magic_loadsound(char *file)
 }
 
 // Affect the canvas on click:
-void alien_click(magic_api * api, int which, int mode,
-                 SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void alien_click(magic_api *api, int which, int mode,
+                 SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     alien_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -273,16 +283,16 @@ void alien_click(magic_api * api, int which, int mode,
 }
 
 // Affect the canvas on release:
-void alien_release(magic_api * api ATTRIBUTE_UNUSED,
+void alien_release(magic_api *api ATTRIBUTE_UNUSED,
                    int which ATTRIBUTE_UNUSED,
-                   SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                   SDL_Surface * last ATTRIBUTE_UNUSED,
-                   int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                   SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                   SDL_Surface *last ATTRIBUTE_UNUSED,
+                   int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void alien_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void alien_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   //Clean up sounds
   int i;
@@ -297,47 +307,47 @@ void alien_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void alien_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                     SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
+void alien_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                     SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
                      Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED,
-                     SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                     SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // Use colors:
-int alien_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int alien_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-Uint8 alien_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 alien_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 6;
 }
 
-Uint8 alien_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 alien_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void alien_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                    SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
-                    Uint8 size, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void alien_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                    SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
+                    Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   alien_RADIUS = size * 4;
 }
 
-void alien_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void alien_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void alien_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                     int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void alien_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                     int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int alien_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int alien_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_FULLSCREEN | MODE_PAINT);
 }
