@@ -6,7 +6,7 @@
 
   Credits: Bill Kendrick<bill@newbreedsoftware.com> & Andrew Corcoran <akanewbie@gmail.com>
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -25,7 +25,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 12, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -39,11 +39,12 @@
 
 // Prototypes
 Uint32 blur_api_version(void);
-int blur_init(magic_api * api, Uint32 disabled_features);
+int blur_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int blur_get_tool_count(magic_api * api);
 SDL_Surface *blur_get_icon(magic_api * api, int which);
 char *blur_get_name(magic_api * api, int which);
 int blur_get_group(magic_api * api, int which);
+int blur_get_order(int which);
 char *blur_get_description(magic_api * api, int which, int mode);
 void blur_drag(magic_api * api, int which, SDL_Surface * canvas,
                SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect);
@@ -89,6 +90,10 @@ const int blur_groups[blur_NUM_TOOLS] = {
   MAGIC_TYPE_DISTORTS,
 };
 
+const int blur_orders[blur_NUM_TOOLS] = {
+  1,
+};
+
 const char *blur_descs[blur_NUM_TOOLS][2] = {
   {gettext_noop("Click and drag the mouse around to blur the image."),
    gettext_noop("Click to blur the entire image.")},
@@ -100,7 +105,7 @@ Uint32 blur_api_version(void)
 }
 
 //Load sounds
-int blur_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int blur_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   int i;
   char fname[1024];
@@ -113,13 +118,13 @@ int blur_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
   return (1);
 }
 
-int blur_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int blur_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (blur_NUM_TOOLS);
 }
 
 // Load our icons:
-SDL_Surface *blur_get_icon(magic_api * api, int which)
+SDL_Surface *blur_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -128,25 +133,31 @@ SDL_Surface *blur_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char *blur_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *blur_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
-  return (strdup(gettext_noop(blur_names[which])));
+  return (strdup(gettext(blur_names[which])));
 }
 
 // Return our group
-int blur_get_group(magic_api * api ATTRIBUTE_UNUSED, int which)
+int blur_get_group(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   return blur_groups[which];
 }
 
-// Return our descriptions, localized:
-char *blur_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+// Return our order
+int blur_get_order(int which)
 {
-  return (strdup(gettext_noop(blur_descs[which][mode - 1])));
+  return blur_orders[which];
+}
+
+// Return our descriptions, localized:
+char *blur_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
+{
+  return (strdup(gettext(blur_descs[which][mode - 1])));
 }
 
 //Do the effect for one pixel
-static void do_blur_pixel(void *ptr, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_blur_pixel(void *ptr, int which ATTRIBUTE_UNUSED, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   magic_api *api = (magic_api *) ptr;
   int i, j, k;
@@ -186,7 +197,7 @@ static void do_blur_pixel(void *ptr, int which ATTRIBUTE_UNUSED, SDL_Surface * c
 }
 
 // Do the effect for the full image
-static void do_blur_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, int which)
+static void do_blur_full(void *ptr, SDL_Surface *canvas, SDL_Surface *last, int which)
 {
   magic_api *api = (magic_api *) ptr;
   int x, y;
@@ -206,7 +217,7 @@ static void do_blur_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, in
 }
 
 //do the effect for the brush
-static void do_blur_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_blur_brush(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   magic_api *api = (magic_api *) ptr;
@@ -224,8 +235,8 @@ static void do_blur_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surfac
 }
 
 // Affect the canvas on drag:
-void blur_drag(magic_api * api, int which, SDL_Surface * canvas,
-               SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void blur_drag(magic_api *api, int which, SDL_Surface *canvas,
+               SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
 
   api->line((void *)api, which, canvas, last, ox, oy, x, y, 1, do_blur_brush);
@@ -254,8 +265,8 @@ void blur_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void blur_click(magic_api * api, int which, int mode,
-                SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void blur_click(magic_api *api, int which, int mode,
+                SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     blur_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -271,16 +282,16 @@ void blur_click(magic_api * api, int which, int mode,
 }
 
 // Affect the canvas on release:
-void blur_release(magic_api * api ATTRIBUTE_UNUSED,
+void blur_release(magic_api *api ATTRIBUTE_UNUSED,
                   int which ATTRIBUTE_UNUSED,
-                  SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                  SDL_Surface * last ATTRIBUTE_UNUSED, int x ATTRIBUTE_UNUSED,
-                  int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                  SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                  SDL_Surface *last ATTRIBUTE_UNUSED, int x ATTRIBUTE_UNUSED,
+                  int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void blur_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void blur_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   //Clean up sounds
   int i;
@@ -295,28 +306,28 @@ void blur_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void blur_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                    SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
-                    Uint8 b ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void blur_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                    SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
+                    Uint8 b ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // Record the size from Tux Paint:
-void blur_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                   SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
-                   Uint8 sz, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void blur_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                   SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
+                   Uint8 sz, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   blur_RADIUS = sz * 4;
 }
 
 // Use colors:
-int blur_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int blur_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
 
-Uint8 blur_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
+Uint8 blur_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -324,22 +335,22 @@ Uint8 blur_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_
     return 0;
 }
 
-Uint8 blur_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 blur_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void blur_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                   int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void blur_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                   int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void blur_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void blur_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int blur_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int blur_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_FULLSCREEN | MODE_PAINT);
 }
