@@ -4,7 +4,7 @@
   Kaleidoscope Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 12, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -45,8 +45,8 @@ static int square_size = 128;
 
 enum
 {
-  KAL_UD,
   KAL_LR,
+  KAL_UD,
   KAL_BOTH,
   KAL_PATTERN,
   KAL_TILES,
@@ -54,8 +54,8 @@ enum
 };
 
 char *kal_icon_names[KAL_COUNT] = {
-  "symmetric_updown.png",
   "symmetric_leftright.png",
+  "symmetric_updown.png",
   "kalidescope.png",
   "kal_pattern.png",
   "kal_tiles.png"
@@ -64,11 +64,12 @@ char *kal_icon_names[KAL_COUNT] = {
 /* Function Declarations: */
 
 Uint32 kalidescope_api_version(void);
-int kalidescope_init(magic_api * api, Uint32 disabled_features);
+int kalidescope_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int kalidescope_get_tool_count(magic_api * api);
 SDL_Surface *kalidescope_get_icon(magic_api * api, int which);
 char *kalidescope_get_name(magic_api * api, int which);
 int kalidescope_get_group(magic_api * api, int which);
+int kalidescope_get_order(int which);
 char *kalidescope_get_description(magic_api * api, int which, int mode);
 static void do_kalidescope(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
 void kalidescope_drag(magic_api * api, int which, SDL_Surface * canvas,
@@ -94,7 +95,7 @@ Uint32 kalidescope_api_version(void)
   return (TP_MAGIC_API_VERSION);
 }
 
-int kalidescope_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int kalidescope_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -104,13 +105,13 @@ int kalidescope_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
   return (1);
 }
 
-int kalidescope_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int kalidescope_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (KAL_COUNT);
 }
 
 // Load our icons:
-SDL_Surface *kalidescope_get_icon(magic_api * api, int which)
+SDL_Surface *kalidescope_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -120,70 +121,75 @@ SDL_Surface *kalidescope_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char *kalidescope_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *kalidescope_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   if (which == KAL_LR)
   {
-    return (strdup(gettext_noop("Symmetric Left/Right")));
+    return (strdup(gettext("Symmetric Left/Right")));
   }
   else if (which == KAL_UD)
   {
-    return (strdup(gettext_noop("Symmetric Up/Down")));
+    return (strdup(gettext("Symmetric Up/Down")));
   }
   else if (which == KAL_PATTERN)
   {
-    return (strdup(gettext_noop("Pattern")));
+    return (strdup(gettext("Pattern")));
   }
   else if (which == KAL_TILES)
   {
-    return (strdup(gettext_noop("Tiles")));
+    return (strdup(gettext("Tiles")));
   }
   else
   {                             /* KAL_BOTH */
-    return (strdup(gettext_noop("Kaleidoscope")));
+    return (strdup(gettext("Kaleidoscope")));
   }
 }
 
 // Return our group (all the same):
-int kalidescope_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int kalidescope_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_PATTERN_PAINTING;
 }
 
+// Return our order:
+int kalidescope_get_order(int which)
+{
+  return 100 + which;
+}
+
 
 // Return our descriptions, localized:
-char *kalidescope_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode ATTRIBUTE_UNUSED)
+char *kalidescope_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode ATTRIBUTE_UNUSED)
 {
   if (which == KAL_LR)
   {
     return (strdup
-            (gettext_noop
+            (gettext
              ("Click and drag the mouse to draw with two brushes that are symmetric across the left and right of your picture.")));
   }
   else if (which == KAL_UD)
   {
     return (strdup
-            (gettext_noop
+            (gettext
              ("Click and drag the mouse to draw with two brushes that are symmetric across the top and bottom of your picture.")));
   }
   else if (which == KAL_PATTERN)
   {
-    return (strdup(gettext_noop("Click and drag the mouse to draw a pattern across the picture.")));
+    return (strdup(gettext("Click and drag the mouse to draw a pattern across the picture.")));
   }
   else if (which == KAL_TILES)
   {
-    return (strdup(gettext_noop("Click and drag the mouse to draw a pattern that is symmetric across the picture.")));
+    return (strdup(gettext("Click and drag the mouse to draw a pattern that is symmetric across the picture.")));
   }
   else
   {                             /* KAL_BOTH */
-    return (strdup(gettext_noop("Click and drag the mouse to draw with symmetric brushes (a kaleidoscope).")));
+    return (strdup(gettext("Click and drag the mouse to draw with symmetric brushes (a kaleidoscope).")));
   }
 }
 
 // Do the effect:
 
-static void do_kalidescope(void *ptr, int which, SDL_Surface * canvas,
-                           SDL_Surface * last ATTRIBUTE_UNUSED, int x, int y)
+static void do_kalidescope(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last ATTRIBUTE_UNUSED, int x, int y)
 {
   magic_api *api = (magic_api *) ptr;
   int xx, yy;
@@ -229,8 +235,8 @@ static void do_kalidescope(void *ptr, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on drag:
-void kalidescope_drag(magic_api * api, int which, SDL_Surface * canvas,
-                      SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void kalidescope_drag(magic_api *api, int which, SDL_Surface *canvas,
+                      SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
   api->line((void *)api, which, canvas, last, ox, oy, x, y, 1, do_kalidescope);
 
@@ -243,38 +249,38 @@ void kalidescope_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void kalidescope_click(magic_api * api, int which, int mode ATTRIBUTE_UNUSED,
-                       SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void kalidescope_click(magic_api *api, int which, int mode ATTRIBUTE_UNUSED,
+                       SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   kalidescope_drag(api, which, canvas, last, x, y, x, y, update_rect);
 }
 
 // Affect the canvas on release:
-void kalidescope_release(magic_api * api, int which ATTRIBUTE_UNUSED,
-                         SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                         SDL_Surface * last ATTRIBUTE_UNUSED,
-                         int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void kalidescope_release(magic_api *api, int which ATTRIBUTE_UNUSED,
+                         SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                         SDL_Surface *last ATTRIBUTE_UNUSED,
+                         int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   api->stopsound();
 }
 
 // No setup happened:
-void kalidescope_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void kalidescope_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   if (kalidescope_snd != NULL)
     Mix_FreeChunk(kalidescope_snd);
 }
 
 // Use colors:
-int kalidescope_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int kalidescope_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 1;
 }
 
 // Record the color from Tux Paint:
-void kalidescope_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                           SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g,
-                           Uint8 b, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void kalidescope_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                           SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g,
+                           Uint8 b, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   kalidescope_r = r;
   kalidescope_g = g;
@@ -282,37 +288,36 @@ void kalidescope_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE
 }
 
 // Use sizes:
-Uint8 kalidescope_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED,
-                                 int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 kalidescope_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return KAL_MAX_SIZE;
 }
 
-Uint8 kalidescope_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 kalidescope_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return KAL_DEF_SIZE;
 }
 
 // Record the size from Tux Paint:
-void kalidescope_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                          SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
-                          Uint8 sz, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void kalidescope_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                          SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
+                          Uint8 sz, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   kalidescope_sz = (sz * 2);
 }
 
 
-void kalidescope_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                          int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void kalidescope_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                          int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void kalidescope_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                           int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void kalidescope_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                           int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int kalidescope_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int kalidescope_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_PAINT);
 }
