@@ -4,7 +4,7 @@
   Negative Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: February 12, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -35,12 +35,13 @@
 static Mix_Chunk *negative_snd;
 static int negative_radius = 16;
 
-int negative_init(magic_api * api, Uint32 disabled_features);
+int negative_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 Uint32 negative_api_version(void);
 int negative_get_tool_count(magic_api * api);
 SDL_Surface *negative_get_icon(magic_api * api, int which);
 char *negative_get_name(magic_api * api, int which);
 int negative_get_group(magic_api * api, int which);
+int negative_get_order(int which);
 char *negative_get_description(magic_api * api, int which, int mode);
 static void do_negative(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
 void negative_drag(magic_api * api, int which, SDL_Surface * canvas,
@@ -89,7 +90,7 @@ const char *negative_descs[negative_NUM_TOOLS][2] = {
 };
 
 
-int negative_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int negative_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -105,13 +106,13 @@ Uint32 negative_api_version(void)
   return (TP_MAGIC_API_VERSION);
 }
 
-int negative_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int negative_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (negative_NUM_TOOLS);
 }
 
 // Load our icon:
-SDL_Surface *negative_get_icon(magic_api * api, int which)
+SDL_Surface *negative_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -120,19 +121,25 @@ SDL_Surface *negative_get_icon(magic_api * api, int which)
 }
 
 // Return our name, localized:
-char *negative_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *negative_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
-  return (strdup(gettext_noop(negative_names[which])));
+  return (strdup(gettext(negative_names[which])));
 }
 
 // Return our group (both the same):
-int negative_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int negative_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_COLOR_FILTERS;
 }
 
+// Return our order:
+int negative_get_order(int which)
+{
+  return 100 + which;
+}
+
 // Return our description, localized:
-char *negative_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+char *negative_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
 {
   int mode_idx;
 
@@ -149,10 +156,10 @@ char *negative_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int
     return NULL;
   }
 
-  return (strdup(gettext_noop(negative_descs[which][mode_idx])));
+  return (strdup(gettext(negative_descs[which][mode_idx])));
 }
 
-static void negative_calc(void *ptr, int which, Uint8 r, Uint8 g, Uint8 b, Uint8 * new_r, Uint8 * new_g, Uint8 * new_b)
+static void negative_calc(void *ptr, int which, Uint8 r, Uint8 g, Uint8 b, Uint8 *new_r, Uint8 *new_g, Uint8 *new_b)
 {
   float h, s, v, new_h;
   magic_api *api = (magic_api *) ptr;
@@ -176,7 +183,7 @@ static void negative_calc(void *ptr, int which, Uint8 r, Uint8 g, Uint8 b, Uint8
 }
 
 // Callback that does the negative color effect on a circle centered around x,y
-static void do_negative(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_negative(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   Uint8 r, g, b, new_r, new_g, new_b;
@@ -197,8 +204,8 @@ static void do_negative(void *ptr, int which, SDL_Surface * canvas, SDL_Surface
 }
 
 // Ask Tux Paint to call our 'do_negative()' callback over a line
-void negative_drag(magic_api * api, int which, SDL_Surface * canvas,
-                   SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void negative_drag(magic_api *api, int which, SDL_Surface *canvas,
+                   SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
   SDL_LockSurface(last);
   SDL_LockSurface(canvas);
@@ -233,8 +240,8 @@ void negative_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Ask Tux Paint to call our 'do_negative()' callback at a single point
-void negative_click(magic_api * api, int which, int mode,
-                    SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void negative_click(magic_api *api, int which, int mode,
+                    SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     negative_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -263,52 +270,52 @@ void negative_click(magic_api * api, int which, int mode,
 }
 
 
-void negative_release(magic_api * api ATTRIBUTE_UNUSED,
+void negative_release(magic_api *api ATTRIBUTE_UNUSED,
                       int which ATTRIBUTE_UNUSED,
-                      SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                      SDL_Surface * last ATTRIBUTE_UNUSED,
-                      int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                      SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                      SDL_Surface *last ATTRIBUTE_UNUSED,
+                      int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 
-void negative_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void negative_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   if (negative_snd != NULL)
     Mix_FreeChunk(negative_snd);
 }
 
 // We don't use colors
-void negative_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                        SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
+void negative_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                        SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
                         Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED,
-                        SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                        SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // We don't use colors
-int negative_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int negative_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void negative_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                       int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void negative_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                       int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void negative_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                        int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void negative_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                        int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int negative_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int negative_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_PAINT | MODE_FULLSCREEN);
 }
 
 
-Uint8 negative_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
+Uint8 negative_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -316,14 +323,14 @@ Uint8 negative_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIB
     return 0;
 }
 
-Uint8 negative_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 negative_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void negative_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                       SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 size,
-                       SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void negative_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                       SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size,
+                       SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   negative_radius = size * 4;
 }
