@@ -7,7 +7,7 @@
   Credits: Adam 'foo-script' Rakowski <foo-script@o2.pl>
   and Bill Kendrick <bill@newbreedsoftware.com>
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -26,7 +26,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 22, 2023
+  Last updated: October 7, 2024
 */
 
 #include "tp_magic_api.h"
@@ -43,16 +43,22 @@ enum
   NUM_TV_TOOLS
 };
 
+int tv_orders[NUM_TV_TOOLS] = {
+  2000,
+  2001,
+};
+
 Mix_Chunk *tv_snd;
 
 Uint32 tv_api_version(void);
 void tv_set_color(magic_api * api, int which, SDL_Surface * canvas,
                   SDL_Surface * last, Uint8 r, Uint8 g, Uint8 b, SDL_Rect * update_rect);
-int tv_init(magic_api * api, Uint32 disabled_features);
+int tv_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int tv_get_tool_count(magic_api * api);
 SDL_Surface *tv_get_icon(magic_api * api, int which);
 char *tv_get_name(magic_api * api, int which);
 int tv_get_group(magic_api * api, int which);
+int tv_get_order(int which);
 char *tv_get_description(magic_api * api, int which, int mode);
 int tv_requires_colors(magic_api * api, int which);
 void tv_release(magic_api * api, int which,
@@ -80,14 +86,14 @@ Uint32 tv_api_version(void)
   return (TP_MAGIC_API_VERSION);
 }
 
-void tv_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                  SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
-                  Uint8 b ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void tv_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                  SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
+                  Uint8 b ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   //get the colors from API and store it in structure
 }
 
-int tv_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int tv_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -97,12 +103,12 @@ int tv_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
   return (1);
 }
 
-int tv_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int tv_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return NUM_TV_TOOLS;
 }
 
-SDL_Surface *tv_get_icon(magic_api * api, int which ATTRIBUTE_UNUSED)
+SDL_Surface *tv_get_icon(magic_api *api, int which ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -111,40 +117,45 @@ SDL_Surface *tv_get_icon(magic_api * api, int which ATTRIBUTE_UNUSED)
   return (IMG_Load(fname));
 }
 
-char *tv_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *tv_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   if (which == TV_TOOL_TV_CLASSIC)
-    return strdup(gettext_noop("TV"));
+    return strdup(gettext("TV"));
   else
-    return strdup(gettext_noop("TV (Bright)"));
+    return strdup(gettext("TV (Bright)"));
 }
 
-int tv_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int tv_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_DISTORTS;
 }
 
-char *tv_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
+int tv_get_order(int which)
 {
-  if (mode == MODE_PAINT)
-    return strdup(gettext_noop("Click and drag to make parts of your picture look like they are on television."));
-  else
-    return strdup(gettext_noop("Click to make your picture look like it's on television."));
+  return tv_orders[which];
 }
 
-int tv_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+char *tv_get_description(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
+{
+  if (mode == MODE_PAINT)
+    return strdup(gettext("Click and drag to make parts of your picture look like they are on television."));
+  else
+    return strdup(gettext("Click to make your picture look like it's on television."));
+}
+
+int tv_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void tv_release(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                SDL_Surface * snapshot ATTRIBUTE_UNUSED,
-                int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void tv_release(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                SDL_Surface *snapshot ATTRIBUTE_UNUSED,
+                int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
-void tv_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void tv_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   Mix_FreeChunk(tv_snd);
 }
@@ -152,7 +163,7 @@ void tv_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 // Interactivity functions
 
 void tv_do_tv(void *ptr_to_api, int which_tool,
-              SDL_Surface * canvas, SDL_Surface * snapshot ATTRIBUTE_UNUSED, int x, int y)
+              SDL_Surface *canvas, SDL_Surface *snapshot ATTRIBUTE_UNUSED, int x, int y)
 {
   magic_api *api = (magic_api *) ptr_to_api;
   int r, g, b, i;
@@ -212,7 +223,7 @@ void tv_do_tv(void *ptr_to_api, int which_tool,
 }
 
 void tv_paint_tv(void *ptr_to_api, int which_tool,
-                 SDL_Surface * canvas, SDL_Surface * snapshot ATTRIBUTE_UNUSED, int x, int y)
+                 SDL_Surface *canvas, SDL_Surface *snapshot ATTRIBUTE_UNUSED, int x, int y)
 {
   int i, j;
   magic_api *api = (magic_api *) ptr_to_api;
@@ -231,8 +242,8 @@ void tv_paint_tv(void *ptr_to_api, int which_tool,
   }
 }
 
-void tv_drag(magic_api * api, int which, SDL_Surface * canvas,
-             SDL_Surface * snapshot, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void tv_drag(magic_api *api, int which, SDL_Surface *canvas,
+             SDL_Surface *snapshot, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
   api->line(api, which, canvas, snapshot, ox, oy, x, y, 1, tv_paint_tv);
 
@@ -243,8 +254,8 @@ void tv_drag(magic_api * api, int which, SDL_Surface * canvas,
   api->playsound(tv_snd, (x * 255) / canvas->w, 255);
 }
 
-void tv_click(magic_api * api, int which, int mode,
-              SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void tv_click(magic_api *api, int which, int mode,
+              SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_FULLSCREEN)
   {
@@ -267,25 +278,25 @@ void tv_click(magic_api * api, int which, int mode,
   }
 }
 
-void tv_switchin(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                 int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void tv_switchin(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                 int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 
 }
 
-void tv_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                  int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void tv_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                  int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 
 }
 
-int tv_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int tv_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_FULLSCREEN | MODE_PAINT);
 }
 
 
-Uint8 tv_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
+Uint8 tv_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -293,14 +304,14 @@ Uint8 tv_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UN
     return 0;
 }
 
-Uint8 tv_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 tv_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void tv_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                 SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 size,
-                 SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void tv_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                 SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size,
+                 SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   tv_radius = size * 4;
 }
