@@ -4,7 +4,7 @@
   Waves Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 19, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -41,11 +41,12 @@ static Mix_Chunk *waves_snd[2];
 /* Local function prototypes: */
 
 Uint32 waves_api_version(void);
-int waves_init(magic_api * api, Uint32 disabled_features);
+int waves_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int waves_get_tool_count(magic_api * api);
 SDL_Surface *waves_get_icon(magic_api * api, int which);
 char *waves_get_name(magic_api * api, int which);
 int waves_get_group(magic_api * api, int which);
+int waves_get_order(int which);
 char *waves_get_description(magic_api * api, int which, int mode);
 void waves_drag(magic_api * api, int which, SDL_Surface * canvas,
                 SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect);
@@ -72,7 +73,7 @@ Uint32 waves_api_version(void)
 
 
 // No setup required:
-int waves_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int waves_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -87,13 +88,13 @@ int waves_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
 }
 
 // We have multiple tools:
-int waves_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int waves_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return 2;
 }
 
 // Load our icons:
-SDL_Surface *waves_get_icon(magic_api * api, int which)
+SDL_Surface *waves_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -106,36 +107,42 @@ SDL_Surface *waves_get_icon(magic_api * api, int which)
 }
 
 // Return our group (both the same):
-int waves_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int waves_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_PICTURE_WARPS;
 }
 
+// Return our order:
+int waves_get_order(int which)
+{
+  return 600 + which;
+}
+
 // Return our names, localized:
-char *waves_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *waves_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   if (!which)
-    return (strdup(gettext_noop("Waves")));
+    return (strdup(gettext("Waves")));
   else
-    return strdup(gettext_noop("Wavelets"));
+    return strdup(gettext("Wavelets"));
 }
 
 // Return our descriptions, localized:
-char *waves_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode ATTRIBUTE_UNUSED)
+char *waves_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode ATTRIBUTE_UNUSED)
 {
   if (!which)
     return (strdup
-            (gettext_noop
+            (gettext
              ("Click to make the picture horizontally wavy. Click toward the top for shorter waves, the bottom for taller waves, the left for small waves, and the right for long waves.")));
   return
-    strdup(gettext_noop
+    strdup(gettext
            ("Click to make the picture vertically wavy. Click toward the top for shorter waves, the bottom for taller waves, the left for small waves, and the right for long waves."));
 }
 
 
-void waves_drag(magic_api * api ATTRIBUTE_UNUSED, int which,
-                SDL_Surface * canvas, SDL_Surface * last,
-                int ox ATTRIBUTE_UNUSED, int oy ATTRIBUTE_UNUSED, int x, int y, SDL_Rect * update_rect)
+void waves_drag(magic_api *api ATTRIBUTE_UNUSED, int which,
+                SDL_Surface *canvas, SDL_Surface *last,
+                int ox ATTRIBUTE_UNUSED, int oy ATTRIBUTE_UNUSED, int x, int y, SDL_Rect *update_rect)
 {
   int xx, yy;
   SDL_Rect src, dest;
@@ -192,24 +199,24 @@ void waves_drag(magic_api * api ATTRIBUTE_UNUSED, int which,
 }
 
 // Affect the canvas on click:
-void waves_click(magic_api * api, int which, int mode ATTRIBUTE_UNUSED,
-                 SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void waves_click(magic_api *api, int which, int mode ATTRIBUTE_UNUSED,
+                 SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   waves_drag(api, which, canvas, last, x, y, x, y, update_rect);
   api->playsound(waves_snd[which], 128, 255);
 }
 
 // Affect the canvas on release:
-void waves_release(magic_api * api ATTRIBUTE_UNUSED,
+void waves_release(magic_api *api ATTRIBUTE_UNUSED,
                    int which ATTRIBUTE_UNUSED,
-                   SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                   SDL_Surface * last ATTRIBUTE_UNUSED,
-                   int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                   SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                   SDL_Surface *last ATTRIBUTE_UNUSED,
+                   int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void waves_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void waves_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   if (waves_snd[0] != NULL)
     Mix_FreeChunk(waves_snd[0]);
@@ -218,47 +225,47 @@ void waves_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void waves_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                     SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
+void waves_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+                     SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
                      Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED,
-                     SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                     SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // Use colors:
-int waves_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int waves_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void waves_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void waves_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void waves_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                     int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void waves_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                     int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int waves_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int waves_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_PAINT);
 }
 
 
-Uint8 waves_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 waves_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-Uint8 waves_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 waves_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void waves_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                    SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
-                    Uint8 size ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void waves_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                    SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
+                    Uint8 size ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
