@@ -5,7 +5,7 @@
   for Tux Paint
 
   Mostly by Albert Cahalan <albert@users.sf.net>
-  Copyright (c) 2002-2006
+  Copyright (c) 2002-2019
 
   http://www.newbreedsoftware.com/tuxpaint/
 
@@ -24,11 +24,10 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  June 14, 2002 - December 30, 2017
+  June 14, 2002 - September 12, 2019
   $Id$
 */
 
-#ifndef __HAIKU__
 #ifdef __GNUC__
 // This version has strict type checking for safety.
 // See the "unnecessary" pointer comparison. (from Linux)
@@ -46,7 +45,6 @@
 #define min(a,b) (((a) < (b)) ? (a) : (b))
 #define max(a,b) (((a) > (b)) ? (a) : (b))
 #endif
-#endif /* Not Haiku */
 
 #define clamp(lo,value,hi)    (min(max(value,lo),hi))
 
@@ -127,3 +125,12 @@
 #undef CLOCK_ASM
 #define CLOCK_ASM(x) x=42
 #endif
+
+/* h/t https://tutel.me/c/programming/questions/45349079/how+to+use+__attribute__fallthrough+correctly+in+gcc */
+#ifndef FALLTHROUGH
+#if defined(__GNUC__) && __GNUC__ >= 7
+#define FALL_THROUGH __attribute__ ((fallthrough))
+#else
+#define FALL_THROUGH ((void)0)
+#endif /* __GNUC__ >= 7 */
+#endif
