@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: June 13, 2023
+  Last updated: June 6, 2024
 */
 
 #ifndef FONTS_H
@@ -28,10 +28,7 @@
 // plan to rip this out as soon as it is considered stable
 //#define THREADED_FONTS
 #define FORKED_FONTS
-#if defined(WIN32) || defined(__BEOS__)
-#undef FORKED_FONTS
-#endif
-#ifdef __ANDROID__
+#if defined(WIN32) || defined(__BEOS__) || defined (__OS2__) || defined(__ANDROID__)
 #undef FORKED_FONTS
 #endif
 
@@ -49,14 +46,15 @@
    based on locale.
 */
 
-typedef struct default_locale_font_s {
+typedef struct default_locale_font_s
+{
   int locale_id;
-  const char * font_name;
-  const char * font_name_fallback;
+  const char *font_name;
+  const char *font_name_fallback;
 } default_locale_font_t;
 
 extern default_locale_font_t default_local_fonts[];
-extern const char * PANGO_DEFAULT_FONT, * PANGO_DEFAULT_FONT_FALLBACK;
+extern const char *PANGO_DEFAULT_FONT, *PANGO_DEFAULT_FONT_FALLBACK;
 
 #include "compiler.h"
 
@@ -177,6 +175,6 @@ void sdl_color_to_pango_color(SDL_Color sdl_color, SDLPango_Matrix * pango_color
 
 int load_user_fonts(SDL_Surface * screen, SDL_Texture * texture,
                     SDL_Renderer * renderer, void *vp, const char *restrict const locale);
-char * ask_pango_for_font(char * pangodesc);
+char *ask_pango_for_font(char *pangodesc);
 
 #endif
