@@ -4,12 +4,12 @@
 
   For Tux Paint
   PostScript(r) printing routine.
-  (for non-Windows, non-Mac OS X, non-BeOS platforms, e.g. Linux)
+  (for non-Windows, non-macOS, non-BeOS platforms; e.g. Linux)
   (moved from tuxpaint.c in 0.9.17)
 
-  Copyright (c) 2008 by Bill Kendrick and others
+  Copyright (c) 2008-2022 by Bill Kendrick and others
   bill@newbreedsoftware.com
-  http://www.tuxpaint.org/
+  https://tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  June 24, 2007 - December 7, 2008
+  June 24, 2007 - December 11, 2022
   $Id$
 */
 
@@ -35,7 +35,7 @@
 
 #include <stdio.h>
 #include <sys/wait.h>
-#include "SDL.h"
+#include "SDL2/SDL.h"
 #include "compiler.h"
 
 
