@@ -40,7 +40,7 @@ static HDC hDCprinter = NULL;
 /**
  * FIXME
  */
-static SDL_Surface *make24bitDIB(SDL_Surface * surf)
+static SDL_Surface *make24bitDIB(SDL_Surface *surf)
 {
   SDL_PixelFormat pixfmt;
   SDL_Surface *surf24;
@@ -65,8 +65,6 @@ static SDL_Surface *make24bitDIB(SDL_Surface * surf)
   pixfmt.Gloss = 0;
   pixfmt.Bloss = 0;
   pixfmt.Aloss = 0;
-  pixfmt.colorkey = 0;
-  pixfmt.alpha = 0;
 
   surf24 = SDL_ConvertSurface(surf, &pixfmt, SDL_SWSURFACE);
   surfDIB = SDL_CreateRGBSurface(SDL_SWSURFACE, surf24->w, surf24->h, 24,
@@ -76,11 +74,11 @@ static SDL_Surface *make24bitDIB(SDL_Surface * surf)
   dst = surfDIB->pixels;
   src = ((Uint8 *) surf24->pixels) + ((surf24->h - 1) * surf24->pitch);
   for (i = 0; i < surf24->h; ++i)
-    {
-      memcpy(dst, src, linesize);
-      src -= surf24->pitch;
-      dst += surfDIB->pitch;
-    }
+  {
+    memcpy(dst, src, linesize);
+    src -= surf24->pitch;
+    dst += surfDIB->pitch;
+  }
 
   SDL_FreeSurface(surf24);      // Free temp surface
 
@@ -107,15 +105,15 @@ static int GetDefaultPrinterStrings(char *device, char *driver, char *output)
 
   if (((dev = strtok(buff, ",")) != NULL) &&
       ((drv = strtok(NULL, ", ")) != NULL) && ((out = strtok(NULL, ", ")) != NULL))
-    {
-      if (device)
-        strcpy(device, dev);
-      if (driver)
-        strcpy(driver, drv);
-      if (output)
-        strcpy(output, out);
-      return 1;
-    }
+  {
+    if (device)
+      strcpy(device, dev);
+    if (driver)
+      strcpy(driver, drv);
+    if (output)
+      strcpy(output, out);
+    return 1;
+  }
   return 0;
 }
 
@@ -197,19 +195,19 @@ static int SaveCustomPrinterHDEVMODE(HWND hWnd, const char *filepath, HANDLE hDe
 
   NOREF(hWnd);
   if ((fp = fopen(filepath, "wb")) != NULL)
-    {
-      DEVMODE *devmode = (DEVMODE *) GlobalLock(hDevMode);
-      int block_size = devmode->dmSize + devmode->dmDriverExtra;
-      int block_written;
-      char devname[dmDeviceNameSize];
+  {
+    DEVMODE *devmode = (DEVMODE *) GlobalLock(hDevMode);
+    int block_size = devmode->dmSize + devmode->dmDriverExtra;
+    int block_written;
+    char devname[dmDeviceNameSize];
 
-      strcpy(devname, (const char *)devmode->dmDeviceName);
-      fwrite(devname, 1, sizeof(devname), fp);
-      block_written = fwrite(devmode, 1, block_size, fp);
-      GlobalUnlock(hDevMode);
-      fclose(fp);
-      return block_size == block_written;
-    }
+    strcpy(devname, (const char *)devmode->dmDeviceName);
+    fwrite(devname, 1, sizeof(devname), fp);
+    block_written = fwrite(devmode, 1, block_size, fp);
+    GlobalUnlock(hDevMode);
+    fclose(fp);
+    return block_size == block_written;
+  }
   return 0;
 }
 
@@ -224,10 +222,10 @@ static int FileExists(const char *filepath)
   FILE *fp;
 
   if ((fp = fopen(filepath, "rb")) != NULL)
-    {
-      fclose(fp);
-      return 1;
-    }
+  {
+    fclose(fp);
+    return 1;
+  }
   return 0;
 }
 
@@ -252,17 +250,17 @@ static int GetCustomPrinterDC(HWND hWnd, const char *printcfg, int show)
   pd.hDevMode = LoadCustomPrinterHDEVMODE(hWnd, printcfg);
 
   if (show || !FileExists(printcfg))
+  {
+    if (PrintDlg(&pd))
     {
-      if (PrintDlg(&pd))
-        {
-          hDCprinter = pd.hDC;
-          SaveCustomPrinterHDEVMODE(hWnd, printcfg, pd.hDevMode);
-          GlobalFree(pd.hDevMode);
-          return 1;
-        }
+      hDCprinter = pd.hDC;
+      SaveCustomPrinterHDEVMODE(hWnd, printcfg, pd.hDevMode);
       GlobalFree(pd.hDevMode);
-      return 0;
+      return 1;
     }
+    GlobalFree(pd.hDevMode);
+    return 0;
+  }
 
   {
     DEVMODE *devmode = (DEVMODE *) GlobalLock(pd.hDevMode);
@@ -297,9 +295,9 @@ static int GetPrinterDC(HWND hWnd, const char *printcfg, int show)
   hDCprinter = NULL;
 
   if (printcfg)
-    {
-      return GetCustomPrinterDC(hWnd, printcfg, show);
-    }
+  {
+    return GetCustomPrinterDC(hWnd, printcfg, show);
+  }
   hDCprinter = GetDefaultPrinterDC();
   return 1;
 }
@@ -320,7 +318,7 @@ int IsPrinterAvailable(void)
 /**
  * FIXME
  */
-const char *SurfacePrint(SDL_Surface * surf, const char *printcfg, int showdialog)
+const char *SurfacePrint(SDL_Window *window, SDL_Surface *surf, const char *printcfg, int showdialog)
 {
   const char *res = NULL;
   HWND hWnd;
@@ -339,15 +337,15 @@ const char *SurfacePrint(SDL_Surface * surf, const char *printcfg, int showdialo
   int scaling = SCALE_TO_FIT;
 
   SDL_VERSION(&wminfo.version);
-  if (!SDL_GetWMInfo(&wminfo))
+  if (!SDL_GetWindowWMInfo(window, &wminfo))
     return "win32_print: SDL_GetWMInfo() failed.";
 
-  hWnd = wminfo.window;
+  hWnd = wminfo.info.win.window;
   if (!GetPrinterDC(hWnd, printcfg, showdialog))
-    {
-      ShowWindow(hWnd, SW_SHOWNORMAL);
-      return NULL;
-    }
+  {
+    ShowWindow(hWnd, SW_SHOWNORMAL);
+    return NULL;
+  }
 
   if (!hDCprinter)
     return "win32_print: GetPrinterDC() failed.";
@@ -362,26 +360,26 @@ const char *SurfacePrint(SDL_Surface * surf, const char *printcfg, int showdialo
 
   nError = StartDoc(hDCprinter, &di);
   if (nError == SP_ERROR)
-    {
-      res = "win32_print: StartDoc() failed.";
-      goto error;
-    }
+  {
+    res = "win32_print: StartDoc() failed.";
+    goto error;
+  }
 
   nError = StartPage(hDCprinter);
   if (nError <= 0)
-    {
-      res = "win32_print: StartPage() failed.";
-      goto error;
-    }
+  {
+    res = "win32_print: StartPage() failed.";
+    goto error;
+  }
 
 //////////////////////////////////////////////////////////////////////////////////////
 
   surf24 = make24bitDIB(surf);
   if (!surf24)
-    {
-      res = "win32_print: make24bitDIB() failed.";
-      goto error;
-    }
+  {
+    res = "win32_print: make24bitDIB() failed.";
+    goto error;
+  }
 
   memset(&bmih, 0, sizeof(bmih));
   bmih.biSize = sizeof(bmih);
@@ -397,100 +395,99 @@ const char *SurfacePrint(SDL_Surface * surf, const char *printcfg, int showdialo
   sY = GetDeviceCaps(hDCprinter, LOGPIXELSY);
 
   switch (scaling)
+  {
+  case STRETCH_TO_FIT:
     {
-    case STRETCH_TO_FIT:
-      {
-        /* stretches x and y dimensions independently to fit the page */
-        /* doesn't preserve image aspect-ratio */
-        rcDst.top = 0;
-        rcDst.left = 0;
-        rcDst.bottom = pageHeight;
-        rcDst.right = pageWidth;
-        break;
-      }
-    case SCALE_TO_FIT:
-      {
-        /* maximises image size on the page */
-        /* preserves aspect-ratio, alignment is top and center */
-        int width = bmih.biWidth;
-        int height = bmih.biHeight;
-
-        if (width < pageWidth && height < pageHeight)
-          {
-            float dW = (float)pageWidth / width;
-            float dH = (float)pageHeight / height;
-
-            if (dW < dH)
-              {
-                width = pageWidth;
-                height = (int)((height * dW * (sY / sX)) + 0.5f);
-              }
-            else
-              {
-                width = (int)((width * dH * (sX / sY)) + 0.5f);
-                height = pageHeight;
-              }
-          }
-        if (width > pageWidth)
-          {
-            height = height * width / pageWidth;
-            width = pageWidth;
-          }
-        if (height > pageHeight)
-          {
-            width = width * height / pageHeight;
-            height = pageHeight;
-          }
-
-        rcDst.top = 0;
-        rcDst.left = (pageWidth - width) / 2;
-        rcDst.bottom = rcDst.top + height;
-        rcDst.right = rcDst.left + width;
-        break;
-      }
-    default:
-      res = "win32_print: invalid scaling option.";
-      goto error;
+      /* stretches x and y dimensions independently to fit the page */
+      /* doesn't preserve image aspect-ratio */
+      rcDst.top = 0;
+      rcDst.left = 0;
+      rcDst.bottom = pageHeight;
+      rcDst.right = pageWidth;
+      break;
     }
+  case SCALE_TO_FIT:
+    {
+      /* maximises image size on the page */
+      /* preserves aspect-ratio, alignment is top and center */
+      int width = bmih.biWidth;
+      int height = bmih.biHeight;
+
+      if (width < pageWidth && height < pageHeight)
+      {
+        float dW = (float)pageWidth / width;
+        float dH = (float)pageHeight / height;
+
+        if (dW < dH)
+        {
+          width = pageWidth;
+          height = (int)((height * dW * (sY / sX)) + 0.5f);
+        }
+        else
+        {
+          width = (int)((width * dH * (sX / sY)) + 0.5f);
+          height = pageHeight;
+        }
+      }
+      if (width > pageWidth)
+      {
+        height = height * width / pageWidth;
+        width = pageWidth;
+      }
+      if (height > pageHeight)
+      {
+        width = width * height / pageHeight;
+        height = pageHeight;
+      }
+
+      rcDst.top = 0;
+      rcDst.left = (pageWidth - width) / 2;
+      rcDst.bottom = rcDst.top + height;
+      rcDst.right = rcDst.left + width;
+      break;
+    }
+  default:
+    res = "win32_print: invalid scaling option.";
+    goto error;
+  }
 
   hDCCaps = GetDeviceCaps(hDCprinter, RASTERCAPS);
 
   if (hDCCaps & RC_PALETTE)
-    {
-      res = "win32_print: printer context requires palette.";
-      goto error;
-    }
+  {
+    res = "win32_print: printer context requires palette.";
+    goto error;
+  }
 
   if (hDCCaps & RC_STRETCHDIB)
-    {
-      SetStretchBltMode(hDCprinter, COLORONCOLOR);
+  {
+    SetStretchBltMode(hDCprinter, COLORONCOLOR);
 
-      bmi.bmiHeader = bmih;
-      nError = StretchDIBits(hDCprinter, rcDst.left, rcDst.top,
-                             rcDst.right - rcDst.left,
-                             rcDst.bottom - rcDst.top,
-                             0, 0, bmih.biWidth, bmih.biHeight,
-                             surf24->pixels, &bmi, DIB_RGB_COLORS, SRCCOPY);
-      if (nError == (int) GDI_ERROR)
-        {
-          res = "win32_print: StretchDIBits() failed.";
-          goto error;
-        }
-    }
-  else
+    bmi.bmiHeader = bmih;
+    nError = StretchDIBits(hDCprinter, rcDst.left, rcDst.top,
+                           rcDst.right - rcDst.left,
+                           rcDst.bottom - rcDst.top,
+                           0, 0, bmih.biWidth, bmih.biHeight, surf24->pixels, &bmi, DIB_RGB_COLORS, SRCCOPY);
+    if (nError == (int)GDI_ERROR)
     {
-      res = "win32_print: StretchDIBits() not available.";
+      res = "win32_print: StretchDIBits() failed.";
       goto error;
     }
+  }
+  else
+  {
+    res = "win32_print: StretchDIBits() not available.";
+    goto error;
+  }
 
 //////////////////////////////////////////////////////////////////////////////////////
 
   nError = EndPage(hDCprinter);
   if (nError <= 0)
-    {
-      res = "win32_print: EndPage() failed.";
-      goto error;
-    }
+  {
+    res = "win32_print: EndPage() failed.";
+    goto error;
+  }
 
   EndDoc(hDCprinter);
 
@@ -570,12 +567,12 @@ char *GetDefaultSaveDir(const char *suffix)
   HRESULT hr = S_OK;
 
   if (SUCCEEDED(hr = ReadRegistry(key, option, prefix, sizeof(prefix))))
-    {
-      remove_slash(prefix);
-      snprintf(path, sizeof(path), "%s/%s", prefix, suffix);
-      _mkdir(path);
-      return strdup(path);
-    }
+  {
+    remove_slash(prefix);
+    snprintf(path, sizeof(path), "%s/%s", prefix, suffix);
+    _mkdir(path);
+    return strdup(path);
+  }
   return strdup("userdata");
 }
 
@@ -594,10 +591,10 @@ char *GetSystemFontDir(void)
   HRESULT hr = S_OK;
 
   if (SUCCEEDED(hr = ReadRegistry(key, option, path, sizeof(path))))
-    {
-      remove_slash(path);
-      return strdup(path);
-    }
+  {
+    remove_slash(path);
+    return strdup(path);
+  }
   return strdup("C:\\WINDOWS\\FONTS");
 }
 
@@ -614,12 +611,12 @@ char *GetUserImageDir(void)
   const char *key = "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders";
   const char *option = "My Pictures";
   HRESULT hr = S_OK;
-  
+
   if (SUCCEEDED(hr = ReadRegistry(key, option, path, sizeof(path))))
-    {
-      remove_slash(path);
-      return strdup(path);
-    }
+  {
+    remove_slash(path);
+    return strdup(path);
+  }
   return strdup("C:\\Pictures");
 }
 
@@ -632,9 +629,9 @@ static char *GetUserTempDir(void)
   const char *temp = getenv("TEMP");
 
   if (!temp)
-    {
-      temp = "userdata";
-    }
+  {
+    temp = "userdata";
+  }
   return strdup(temp);
 }
 
@@ -674,14 +671,14 @@ LRESULT CALLBACK LowLevelKeyboardProc(int nCode, WPARAM wParam, LPARAM lParam)
     return CallNextHookEx(g_hKeyboardHook, nCode, wParam, lParam);
 
   switch (wParam)
+  {
+  case WM_KEYDOWN:
+  case WM_KEYUP:
     {
-    case WM_KEYDOWN:
-    case WM_KEYUP:
-      {
-        bEatKeystroke = g_bWindowActive && ((p->vkCode == VK_LWIN) || (p->vkCode == VK_RWIN));
-        break;
-      }
+      bEatKeystroke = g_bWindowActive && ((p->vkCode == VK_LWIN) || (p->vkCode == VK_RWIN));
+      break;
     }
+  }
 
   if (bEatKeystroke)
     return 1;
