@@ -15,7 +15,7 @@
 #endif
 
 /* if printcfg is NULL, uses the default printer */
-extern const char *SurfacePrint(SDL_Surface * surf, const char *printcfg, int showdialog);
+extern const char *SurfacePrint(SDL_Window * window, SDL_Surface * surf, const char *printcfg, int showdialog);
 extern int IsPrinterAvailable(void);
 
 /* additional windows functions requiring <windows.h> */
